@@ -1,8 +1,7 @@
 """Main module."""
 
 import os
-import time
-from datetime import datetime, date, time, timezone
+from datetime import datetime, date, timezone
 import json
 
 import shlex
@@ -36,6 +35,7 @@ import boto3
 import os
 # from aws_pcluster_helpers import (SinfoRow, SInfoTable)
 from aws_pcluster_helpers.models.sinfo import (SInfoTable, SinfoRow)
+import time
 
 pcluster_spawner_template_paths = os.path.join(os.path.dirname(__file__), 'templates')
 
@@ -63,8 +63,8 @@ from jupyterhub.spawner import set_user_setuid
 class PClusterSlurmSpawner(batchspawner.SlurmSpawner):
     # This is tied to the dict returned by the submission_data function
     batch_script = Unicode("""#!/bin/bash
-#SBATCH --output={{homedir}}/{{job_prefix}}_%j.log
-#SBATCH --job-name={{job_prefix}}
+#SBATCH --output={{homedir}}/jupyterhub_%j.log
+#SBATCH --job-name=jupyterhub
 #SBATCH --chdir={{homedir}}
 #SBATCH --export={{keepvars}}
 #SBATCH --get-user-env=L
@@ -499,5 +499,5 @@ echo "jupyterhub-singleuser ended gracefully"
 
 
 def get_ec2_address(address_type='public_ipv4') -> str:
-    response = requests.get(' http://169.254.169.254/latest/meta-data/public-ipv4')
-    return reponse.content.decode('utf-8')
+    response = requests.get(f'http://169.254.169.254/latest/meta-data/{address_type}')
+    return response.content.decode('utf-8')
